Django Animate on Scroll
========================

An extension for Django CMS that adds the aos library to animate elements on your page as you scroll.

Installation
------------

1. Install with pip ``pip install djangocms-animate-on-scroll``

2. Add ``djangocms_animate_on_scroll`` to INSTALLED_APPS

3. Run migrations ``python manage.py migrate``


Usage
-----

After installation simply add the plugins to the page.
